@@ -23,15 +23,16 @@
 
 #include <QApplication>
 #include <QFile>
-#include <QLayout>
 #include <QUrl>
+#include <QHBoxLayout>
+#include <QVBoxLayout>
+#include <QGridLayout>
 
 #include <kmessagebox.h>
 #include <kdialog.h>
 #include <KLocalizedString>
 
 #include "kcmsambalog.h"
-#include "kcmsambalog.moc"
 
 #define LOG_SCREEN_XY_OFFSET 10
 
@@ -106,7 +107,7 @@ LogView::LogView(QWidget *parent, KConfig *config) :
 	showFileOpen.setChecked(false);
 	showFileClose.setChecked(false);
 
-	connect(&updateButton, SIGNAL(clicked()), this, SLOT(updateList()));
+	connect(&updateButton, &QPushButton::clicked, this, &LogView::updateList);
 	emit contentsChanged(&viewHistory, 0, 0);
 
 	label.setMinimumSize(label.sizeHint());
